@@ -22,6 +22,7 @@ import uuid
 import octobot_commons.constants as constants
 import octobot_commons.logging as commons_logging
 import octobot_commons.json_util as json_util
+import octobot_commons.errors as errors
 
 
 class Profile:
@@ -65,6 +66,7 @@ class Profile:
         self.description: str = None
         self.avatar: str = None
         self.avatar_path: str = None
+        self.origin_url: str = None
         self.read_only: bool = False
         self.imported: bool = False
 
@@ -82,6 +84,7 @@ class Profile:
             self.name = profile_config.get(constants.CONFIG_NAME, "")
             self.description = profile_config.get(constants.CONFIG_DESCRIPTION, "")
             self.avatar = profile_config.get(constants.CONFIG_AVATAR, "")
+            self.origin_url = profile_config.get(constants.CONFIG_ORIGIN_URL, None)
             self.read_only = profile_config.get(constants.CONFIG_READ_ONLY, False)
             self.imported = profile_config.get(constants.CONFIG_IMPORTED, False)
             self.config = parsed_profile[constants.PROFILE_CONFIG]
@@ -154,17 +157,29 @@ class Profile:
         with open(self.config_file(), "w") as profile_file:
             json.dump(self.as_dict(), profile_file, indent=4, sort_keys=True)
 
-    def rename_folder(self, new_name) -> str:
+    def rename_folder(self, new_name, should_raise) -> str:
         """
         rename the profile folder
         :param new_name: name of the new folder
+        :param should_raise: raises ProfileConflictError if the profile can't be renamed
         :return: the new profile path
         """
         new_path = os.path.join(os.path.split(self.path)[0], new_name)
         if os.path.exists(new_path):
-            raise RuntimeError(
-                "Skipping folder renaming: a profile already exists at this path"
+            if should_raise:
+                raise errors.ProfileConflictError(
+                    "Skipping folder renaming: a profile already exists at this path"
+                )
+            return self.path
+        try:
+            os.rename(self.path, new_path)
+            self.path = new_path
+        except Exception as err:
+            commons_logging.get_logger("ProfileRenamer").error(
+                f"Error when renaming profile: {err}"
             )
+            raise errors.ProfileConflictError from err
+        return self.path
 
     def duplicate(self, name: str = None, description: str = None):
         """
@@ -179,6 +194,7 @@ class Profile:
         clone.profile_id = str(uuid.uuid4())
         clone.read_only = False
         clone.imported = False
+        clone.origin_url = None
         try:
             clone.path = os.path.join(
                 os.path.split(self.path)[0], f"{clone.name}_{clone.profile_id}"
@@ -207,6 +223,7 @@ class Profile:
                 constants.CONFIG_NAME: self.name,
                 constants.CONFIG_DESCRIPTION: self.description,
                 constants.CONFIG_AVATAR: self.avatar,
+                constants.CONFIG_ORIGIN_URL: self.origin_url,
                 constants.CONFIG_READ_ONLY: self.read_only,
                 constants.CONFIG_IMPORTED: self.imported,
             },
